"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDropdownYears = void 0;
const addYears_1 = require("date-fns/addYears");
const endOfYear_1 = require("date-fns/endOfYear");
const isBefore_1 = require("date-fns/isBefore");
const isSameYear_1 = require("date-fns/isSameYear");
const startOfMonth_1 = require("date-fns/startOfMonth");
const startOfYear_1 = require("date-fns/startOfYear");
/** Return the years to show in the dropdown. */
function getDropdownYears(props, month) {
    if (!props.startMonth)
        return undefined;
    if (!props.endMonth)
        return undefined;
    const firstNavYear = (0, startOfYear_1.startOfYear)(props.startMonth);
    const lastNavYear = (0, endOfYear_1.endOfYear)(props.endMonth);
    const years = [];
    let year = firstNavYear;
    while ((0, isBefore_1.isBefore)(year, lastNavYear) || (0, isSameYear_1.isSameYear)(year, lastNavYear)) {
        years.push(year.getFullYear());
        year = (0, addYears_1.addYears)(year, 1);
    }
    return years.map((value) => {
        const disabled = (month &&
            props.startMonth &&
            new Date(value, month) < (0, startOfMonth_1.startOfMonth)(props.startMonth)) ||
            (month &&
                props.endMonth &&
                new Date(value, month) > (0, startOfMonth_1.startOfMonth)(props.endMonth)) ||
            false;
        const label = props.formatters.formatYearDropdown(value);
        return {
            value,
            label,
            disabled
        };
    });
}
exports.getDropdownYears = getDropdownYears;
//# sourceMappingURL=getDropdownYears.js.map