"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getStartEndMonths = void 0;
const addYears_1 = require("date-fns/addYears");
const endOfMonth_1 = require("date-fns/endOfMonth");
const endOfYear_1 = require("date-fns/endOfYear");
const startOfDay_1 = require("date-fns/startOfDay");
const startOfMonth_1 = require("date-fns/startOfMonth");
const startOfYear_1 = require("date-fns/startOfYear");
/**
 * Return the `fromMonth` and `toMonth` prop values values parsing the DayPicker
 * props.
 */
function getStartEndMonths(props) {
    let { startMonth, endMonth } = props;
    // Handle deprecated code
    const { fromYear, toYear, fromMonth, toMonth } = props;
    if (!startMonth && fromMonth) {
        startMonth = fromMonth;
    }
    if (!startMonth && fromYear) {
        startMonth = new Date(fromYear, 0, 1);
    }
    if (!endMonth && toMonth) {
        endMonth = toMonth;
    }
    if (!endMonth && toYear) {
        endMonth = new Date(toYear, 11, 31);
    }
    const hasDropdowns = props.captionLayout?.startsWith("dropdown");
    if (startMonth) {
        startMonth = (0, startOfMonth_1.startOfMonth)(startMonth);
    }
    else if (fromYear) {
        startMonth = new Date(fromYear, 0, 1);
    }
    else if (!startMonth && hasDropdowns) {
        startMonth = (0, startOfYear_1.startOfYear)((0, addYears_1.addYears)(props.today ?? new Date(), -100));
    }
    if (endMonth) {
        endMonth = (0, endOfMonth_1.endOfMonth)(endMonth);
    }
    else if (toYear) {
        endMonth = new Date(toYear, 11, 31);
    }
    else if (!endMonth && hasDropdowns) {
        endMonth = (0, endOfYear_1.endOfYear)(props.today ?? new Date());
    }
    return {
        startMonth: startMonth ? (0, startOfDay_1.startOfDay)(startMonth) : startMonth,
        endMonth: endMonth ? (0, startOfDay_1.startOfDay)(endMonth) : endMonth
    };
}
exports.getStartEndMonths = getStartEndMonths;
//# sourceMappingURL=getStartEndMonths.js.map