import React, { SelectHTMLAttributes } from "react";
import type { Month } from "date-fns";
/** An option to use in the dropdown. Maps to the `<option>` HTML element. */
export type DropdownOption = {
    /** The value of the option. */
    value: Month | number;
    /** The label of the option. */
    label: string;
    /**
     * The dropdown option is disabled when it cannot be selected because out of
     * the calendar range.
     */
    disabled: boolean;
};
/**
 * Render a dropdown component to use in the navigation bar.
 *
 * Use the `components` prop to swap this component with a custom one.
 *
 * @group Components
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export declare function Dropdown(props: {
    options?: DropdownOption[] | undefined;
    rootClassName?: string;
} & Omit<SelectHTMLAttributes<HTMLSelectElement>, "children">): React.JSX.Element;
export type DropdownProps = Parameters<typeof Dropdown>[0];
