import React, { PropsWithChildren } from "react";
import { V9DeprecatedProps } from "../types";
import type { ClassNames, DataAttributes, DayPickerProps, Formatters, Labels, Mode, PropsBase, Selected, SelectHandler } from "../types";
/**
 * Holds the props passed to the DayPicker component, with some optional props
 * set to meaningful defaults.
 *
 * Access this context using the {@link useProps} hook.
 *
 * @template T - The {@link Mode | selection mode}. Defaults to `"default"`.
 * @template R - Whether the selection is required. Defaults to `false`.
 * @group Contexts
 */
export interface PropsContext<T extends Mode = "default", R extends boolean = false> extends Omit<PropsBase, V9DeprecatedProps> {
    classNames: ClassNames;
    /** The `data-*` attributes passed to `<DayPicker />`. */
    dataAttributes: DataAttributes;
    endMonth: Date | undefined;
    formatters: Formatters;
    id: string;
    labels: Labels;
    max: number | undefined;
    min: number | undefined;
    mode: T;
    numberOfMonths: number;
    required: boolean;
    startMonth: Date | undefined;
    today: Date;
    /** The currently selected value. */
    selected: Selected<Mode, R> | undefined;
    /** The default selected value. */
    defaultSelected: Selected<Mode, R> | undefined;
    /** The function that handles the day selection. */
    onSelect: SelectHandler<Mode, R> | undefined;
}
/**
 * Provide the props to the DayPicker components. Must be used as root of the
 * other providers.
 *
 * @private
 */
export declare function PropsProvider<T extends Mode, R extends boolean>(props: PropsWithChildren<DayPickerProps<T, R>>): React.JSX.Element;
/**
 * Access to the props passed to DayPicker.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export declare function useProps(): PropsContext<Mode, boolean>;
