import React, { createContext, useContext, useId } from "react";
import { getDataAttributes } from "../helpers/getDataAttributes";
import { getDefaultClassNames } from "../helpers/getDefaultClassNames";
import { getFormatters } from "../helpers/getFormatters";
import { getStartEndMonths } from "../helpers/getStartEndMonths";
import * as defaultLabels from "../labels";
const propsContext = createContext(null);
/**
 * Provide the props to the DayPicker components. Must be used as root of the
 * other providers.
 *
 * @private
 */
export function PropsProvider(props) {
    const reactId = useId();
    const { startMonth, endMonth } = getStartEndMonths(props);
    const { children, 
    // Remove deprecated props
    fromDate, fromMonth, fromYear, toDate, toMonth, toYear, ...restProps } = props;
    const context = {
        ...restProps,
        classNames: { ...getDefaultClassNames(), ...restProps.classNames },
        dataAttributes: getDataAttributes(props),
        endMonth,
        formatters: getFormatters(props.formatters),
        id: props.id ?? reactId,
        labels: { ...defaultLabels, ...restProps.labels },
        max: "max" in props ? props.max ?? undefined : undefined,
        min: "min" in props ? props.min ?? undefined : undefined,
        mode: props.mode ?? "default",
        numberOfMonths: props.numberOfMonths ?? 1,
        required: "required" in props ? props.required ?? false : false,
        startMonth,
        today: props.today ?? new Date(),
        selected: "selected" in props ? props.selected : undefined,
        defaultSelected: "defaultSelected" in props ? props.defaultSelected : undefined,
        onSelect: "onSelect" in props ? props.onSelect : undefined
    };
    return (React.createElement(propsContext.Provider, { value: context }, children));
}
/**
 * Access to the props passed to DayPicker.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export function useProps() {
    const context = useContext(propsContext);
    if (!context) {
        throw new Error("useDayPicker() must be used within a `<dayPickerContext.Provider/>`.");
    }
    return context;
}
//# sourceMappingURL=props.js.map